==> kubernetes-model-admissionregistration-4.13.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectRulesReviewStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubjectRulesReviewStatusBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusBuilder> {

    io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent;
    Boolean validationEnabled;

    public SubjectRulesReviewStatusBuilder() { 
        this(true);
    }


    public SubjectRulesReviewStatusBuilder(Boolean validationEnabled) { 
        this(new SubjectRulesReviewStatus(), validationEnabled);
    }


    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent) { 
        this(fluent, true);
    }


    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SubjectRulesReviewStatus(), validationEnabled);
    }


    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance) { 
        this(fluent, instance, true);
    }


    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withEvaluationError(instance.getEvaluationError()); 
        fluent.withIncomplete(instance.getIncomplete()); 
        fluent.withNonResourceRules(instance.getNonResourceRules()); 
        fluent.withResourceRules(instance.getResourceRules()); 
        this.validationEnabled = validationEnabled; 
    }


    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance) { 
        this(instance,true);
    }


    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withEvaluationError(instance.getEvaluationError()); 
        this.withIncomplete(instance.getIncomplete()); 
        this.withNonResourceRules(instance.getNonResourceRules()); 
        this.withResourceRules(instance.getResourceRules()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus build() {
        SubjectRulesReviewStatus buildable = new SubjectRulesReviewStatus(fluent.getEvaluationError(),fluent.isIncomplete(),fluent.getNonResourceRules(),fluent.getResourceRules());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubjectRulesReviewStatusBuilder that = (SubjectRulesReviewStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectRulesReviewStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SubjectRulesReviewStatusBuilder extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusBuilder> {

    io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent;
    Boolean validationEnabled;

    public SubjectRulesReviewStatusBuilder() {
        this(true);
    }

    public SubjectRulesReviewStatusBuilder(Boolean validationEnabled) {
        this(new SubjectRulesReviewStatus(), validationEnabled);
    }

    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SubjectRulesReviewStatus(), validationEnabled);
    }

    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance) {
        this(fluent, instance, true);
    }

    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withEvaluationError(instance.getEvaluationError()); 
        fluent.withIncomplete(instance.getIncomplete()); 
        fluent.withNonResourceRules(instance.getNonResourceRules()); 
        fluent.withResourceRules(instance.getResourceRules()); 
        this.validationEnabled = validationEnabled; 
    }

    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance) {
        this(instance,true);
    }

    public SubjectRulesReviewStatusBuilder(io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withEvaluationError(instance.getEvaluationError()); 
        this.withIncomplete(instance.getIncomplete()); 
        this.withNonResourceRules(instance.getNonResourceRules()); 
        this.withResourceRules(instance.getResourceRules()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatus build() {
        SubjectRulesReviewStatus buildable = new SubjectRulesReviewStatus(fluent.getEvaluationError(),fluent.getIncomplete(),fluent.getNonResourceRules(),fluent.getResourceRules());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SubjectRulesReviewStatusBuilder that = (SubjectRulesReviewStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
